@@ -1621,7 +1621,7 @@ $default_ttl = $current_config['default_ttl'] ?? 3600;
 <?php endif; ?>
 
 <script>
-// Copy to clipboard function
+// Copy to clipboard function with fallback
 function copyToClipboard(text) {
     if (typeof text !== 'string') {
         // If text is an element ID, get the text content
@@ -1629,13 +1629,44 @@ function copyToClipboard(text) {
         text = element ? element.textContent : text;
     }
     
-    navigator.clipboard.writeText(text).then(function() {
-        // Show temporary success message
-        showAlert('Copied to clipboard!', 'success');
-    }).catch(function(err) {
-        console.error('Could not copy text: ', err);
-        showAlert('Failed to copy to clipboard', 'danger');
-    });
+    // Check if modern clipboard API is available and we're in secure context
+    if (navigator.clipboard && window.isSecureContext) {
+        navigator.clipboard.writeText(text).then(function() {
+            showAlert('Copied to clipboard!', 'success');
+        }).catch(function(err) {
+            console.error('Clipboard API failed: ', err);
+            fallbackCopyToClipboard(text);
+        });
+    } else {
+        // Fallback for older browsers or non-HTTPS
+        fallbackCopyToClipboard(text);
+    }
+}
+
+// Fallback copy method using execCommand
+function fallbackCopyToClipboard(text) {
+    const textArea = document.createElement('textarea');
+    textArea.value = text;
+    textArea.style.position = 'fixed';
+    textArea.style.left = '-999999px';
+    textArea.style.top = '-999999px';
+    document.body.appendChild(textArea);
+    textArea.focus();
+    textArea.select();
+    
+    try {
+        const successful = document.execCommand('copy');
+        if (successful) {
+            showAlert('Copied to clipboard!', 'success');
+        } else {
+            showAlert('Failed to copy to clipboard', 'danger');
+        }
+    } catch (err) {
+        console.error('Fallback copy failed: ', err);
+        showAlert('Copy to clipboard not supported', 'warning');
+    } finally {
+        document.body.removeChild(textArea);
+    }
 }
 </script>
 
