@@ -35,17 +35,17 @@ function whp_ConfigOptions() {
             'Default' => '1',
             'Description' => 'Number of CPU cores allocated',
         ),
-        'Memory (GB)' => array(
+        'Memory (MB)' => array(
             'Type' => 'text',
             'Size' => '10',
-            'Default' => '1',
-            'Description' => 'Memory allocation in GB',
+            'Default' => '512',
+            'Description' => 'Memory allocation in MB',
         ),
-        'Disk Space (GB)' => array(
+        'Disk Space (MB)' => array(
             'Type' => 'text',
             'Size' => '10',
-            'Default' => '5',
-            'Description' => 'Disk space allocation in GB',
+            'Default' => '1000',
+            'Description' => 'Disk space allocation in MB',
         ),
         'Domains' => array(
             'Type' => 'text',
@@ -62,9 +62,15 @@ function whp_ConfigOptions() {
         'Email Accounts' => array(
             'Type' => 'text',
             'Size' => '10',
-            'Default' => '5',
+            'Default' => '0',
             'Description' => 'Number of email accounts allowed',
         ),
+        'Email Storage (MB)' => array(
+            'Type' => 'text',
+            'Size' => '10',
+            'Default' => '1000',
+            'Description' => 'Total email storage allocation in MB',
+        ),
         'Databases' => array(
             'Type' => 'text',
             'Size' => '10',
@@ -99,12 +105,13 @@ function whp_CreateAccount(array $params) {
             'username' => $username,
             'password' => $password,
             'resources' => array(
-                'cpu_cores' => floatval($configoptions['CPU Cores'] ?: 1),
-                'memory_gb' => floatval($configoptions['Memory (GB)'] ?: 1),
-                'disk_gb' => floatval($configoptions['Disk Space (GB)'] ?: 5),
+                'cpu_cores' => floatval($configoptions['CPU Cores'] ?: 0.5),
+                'memory_mb' => intval($configoptions['Memory (MB)'] ?: 512),
+                'disk_mb' => intval($configoptions['Disk Space (MB)'] ?: 1000),
                 'domains' => intval($configoptions['Domains'] ?: 1),
                 'sites' => intval($configoptions['Sites'] ?: 1),
-                'email_accounts' => intval($configoptions['Email Accounts'] ?: 5),
+                'email_accounts' => intval($configoptions['Email Accounts'] ?: 0),
+                'email_storage_mb' => intval($configoptions['Email Storage (MB)'] ?: 1000),
                 'databases' => intval($configoptions['Databases'] ?: 1),
                 'api_enabled' => $configoptions['API Access'] === 'on',
                 'api_rate_limit' => intval($configoptions['API Rate Limit'] ?: 100),
@@ -252,12 +259,13 @@ function whp_ChangePackage(array $params) {
         $apiData = array(
             'username' => $username,
             'resources' => array(
-                'cpu_cores' => floatval($configoptions['CPU Cores'] ?: 1),
-                'memory_gb' => floatval($configoptions['Memory (GB)'] ?: 1),
-                'disk_gb' => floatval($configoptions['Disk Space (GB)'] ?: 5),
+                'cpu_cores' => floatval($configoptions['CPU Cores'] ?: 0.5),
+                'memory_mb' => intval($configoptions['Memory (MB)'] ?: 512),
+                'disk_mb' => intval($configoptions['Disk Space (MB)'] ?: 1000),
                 'domains' => intval($configoptions['Domains'] ?: 1),
                 'sites' => intval($configoptions['Sites'] ?: 1),
-                'email_accounts' => intval($configoptions['Email Accounts'] ?: 5),
+                'email_accounts' => intval($configoptions['Email Accounts'] ?: 0),
+                'email_storage_mb' => intval($configoptions['Email Storage (MB)'] ?: 1000),
                 'databases' => intval($configoptions['Databases'] ?: 1),
                 'api_enabled' => $configoptions['API Access'] === 'on',
                 'api_rate_limit' => intval($configoptions['API Rate Limit'] ?: 100),
